from django.db import models

from django_bleach import forms
from django_bleach.forms import default_widget
from django.conf import settings


class BleachField(models.TextField):

    def __init__(self, allowed_tags=None, allowed_styles=None,
        allowed_attributes=None, strip_tags=None, strip_comments=None,
        *args, **kwargs):

        super(BleachField, self).__init__(*args, **kwargs)

        self.formfield_defaults = {}

        if allowed_tags is not None:
            self.formfield_defaults['allowed_tags'] = allowed_tags
        if allowed_attributes is not None:
            self.formfield_defaults['allowed_attributes'] = allowed_attributes
        if allowed_styles is not None:
            self.formfield_defaults['allowed_styles'] = allowed_styles
        if strip_tags is not None:
            self.formfield_defaults['strip_tags'] = strip_tags
        if strip_comments is not None:
            self.formfield_defaults['strip_comments'] = strip_comments

    def formfield(self, **kwargs):
        options = {
            'form_class': forms.BleachField,
            'widget': default_widget,
        }
        options.update(self.formfield_defaults)
        options.update(kwargs)
        return super(BleachField, self).formfield(**options)


if 'south' in settings.INSTALLED_APPS:
    from south.modelsinspector import add_introspection_rules
    # Bleach attributes don't influence on data representation so we use
    # default introspection rules of TextField
    add_introspection_rules([], ['^django_bleach\.models\.BleachField'])



import bleach

from django import template
from django.conf import settings
from django.utils.safestring import mark_safe

register = template.Library()


bleach_args = {}

possible_settings = {
    'BLEACH_ALLOWED_TAGS': 'tags',
    'BLEACH_ALLOWED_ATTRIBUTES': 'attributes',
    'BLEACH_ALLOWED_STYLES': 'styles',
    'BLEACH_STRIP_TAGS': 'strip',
    'BLEACH_STRIP_COMMENTS': 'strip_comments',
}

for setting, kwarg in possible_settings.items():
    if hasattr(settings, setting):
        bleach_args[kwarg] = getattr(settings, setting)


def bleach_value(value):
    bleached_value = bleach.clean(value, **bleach_args)
    return mark_safe(bleached_value)

register.filter('bleach', bleach_value)

@register.filter
def bleach_linkify(value):
    return bleach.linkify(value, parse_email=True)


#!/usr/bin/env python

try:
    from setuptools import setup, find_packages
except ImportError:
    from ez_setup import use_setuptools
    use_setuptools()
    from setuptools import setup, find_packages

setup(
    name='django-bleach',
    version="0.2.1",
    description='Easily use bleach with Django models and templates',
    author='Tim Heap',
    author_email='tim@timheap.me',
    url='https://bitbucket.org/ionata/django-bleach',
    packages=find_packages(),
    install_requires=[
        'bleach',
        'Django>=1.3',
    ],
    package_data={},
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Framework :: Django',
    ],
)
